==> firefox-58.0b13.source.tar.xz: firefox-58.0b13/browser/extensions/activity-stream/prerendered/locales/kab/activity-stream-strings.js <==
// Note - this is a generated file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Iccer amaynut",
  "default_label_loading": "Asali…",
  "header_top_sites": "Ismal ifazen",
  "header_stories": "Tiqsiɣin ifazen",
  "header_highlights": "Asebrureq",
  "header_visit_again": "Rzu tikelt-nniḍen",
  "header_bookmarks": "Ticraḍ n melmi kan",
  "header_recommended_by": "Iwelleh-it-id {provider}",
  "header_bookmarks_placeholder": "Ur ɣur-k ara ticraḍ yakan.",
  "header_stories_from": "seg",
  "type_label_visited": "Yettwarza",
  "type_label_bookmarked": "Yettwacreḍ",
  "type_label_synced": "Yemtawi seg ibenk-nniḍen",
  "type_label_recommended": "Tiddin",
  "type_label_open": "Yeldi",
  "type_label_topic": "Asentel",
  "type_label_now": "Tura",
  "menu_action_bookmark": "Creḍ asebter-agi",
  "menu_action_remove_bookmark": "Kkes tacreṭ-agi",
  "menu_action_copy_address": "Nγel tansa",
  "menu_action_email_link": "Azen aseγwen s yimayl…",
  "menu_action_open_new_window": "Ldei deg usfaylu amaynut",
  "menu_action_open_private_window": "Ldi deg usfaylu uslig amaynut",
  "menu_action_dismiss": "Kkes",
  "menu_action_delete": "Kkes seg umazray",
  "menu_action_pin": "Senteḍ",
  "menu_action_unpin": "Serreḥ",
  "confirm_history_delete_p1": "Tebɣiḍ ad tekksed yal tummant n usebter-agi seg umazray-ik?",
  "confirm_history_delete_notice_p2": "Tigawt-agi ur tettuɣal ara ar deffir.",
  "menu_action_save_to_pocket": "Sekles ɣer Pocket",
  "search_for_something_with": "Nadi γef {search_term} s:",
  "search_button": "Nadi",
  "search_header": "Anadi {search_engine_name}",
  "search_web_placeholder": "Nadi di Web",
  "search_settings": "Snifel iγewwaṛen n unadi",
  "section_info_option": "Talɣut",
  "section_info_send_feedback": "Azen tikti",
  "section_info_privacy_notice": "Tasertit n tbaḍnit",
  "section_disclaimer_topstories": "The most interesting stories on the web, selected based on what you read. From Pocket, now part of Mozilla.",
  "section_disclaimer_topstories_linktext": "Learn how it works.",
  "section_disclaimer_topstories_buttontext": "Okay, got it",
  "welcome_title": "Ansuf ar yiccer amaynut",
  "welcome_body": "Firefox ad iseqdec tallunt akken ad d-yesken akk ticraḍ n isebtar iwulmen, imagraden, tividyutin, akked isebtar aniɣer terziḍ melmi kan, ihi tzemreḍ ad d-uɣaleḍ ɣer-sen s wudem fessusen.",
  "welcome_label": "Asulu n iferdisen tisura",
  "time_label_less_than_minute": "<1 n tesdat",
  "time_label_minute": "{number} n tesdatin",
  "time_label_hour": "{number} n isragen",
  "time_label_day": "{number}n wussan",
  "settings_pane_button_label": "Sagen asebter n yiccer-ik amaynut",
  "settings_pane_header": "Ismenyifen n yiccer amaynut",
  "settings_pane_body2": "Fren ayen ad twaliḍ deg usebter-agi.",
  "settings_pane_search_header": "Nadi",
  "settings_pane_search_body": "Nadi di Web seg iccer-ik amaynut.",
  "settings_pane_topsites_header": "Ismal ifazen",
  "settings_pane_topsites_body": "Kcem ar yesmal web i trezzuḍ s waṭas.",
  "settings_pane_topsites_options_showmore": "Sken sin izirigen",
  "settings_pane_bookmarks_header": "Ticraḍ n melmi kan",
  "settings_pane_bookmarks_body": "Ticraḍ yettwarnan melmi kan deg iwen n umdiq ɣef afus.",
  "settings_pane_visit_again_header": "Rzu tikelt-nniḍen",
  "settings_pane_visit_again_body": "Firefox ad d-yesken tukkist n umazray-ik n tunigin i tzemreḍ ad twalid tikelt-nniḍen.",
  "settings_pane_highlights_header": "Asebrureq",
  "settings_pane_highlights_body2": "Aff abrid-ik γer wayen i tḥemmleḍ i γef terziḍ yakan neγ tcerḍeḍ-t.",
  "settings_pane_highlights_options_bookmarks": "Ticraḍ n isebtar",
  "settings_pane_highlights_options_visited": "Ismal yettwarzan",
  "settings_pane_snippets_header": "Tiwzillin",
  "settings_pane_snippets_body": "Wali issalen n Mozilla γef Firefox, adlis internet, akked issalen nniṣen sya γer da.",
  "settings_pane_done_button": "Immed",
  "settings_pane_topstories_options_sponsored": "Show Sponsored Stories",
  "edit_topsites_button_text": "Ẓreg",
  "edit_topsites_button_label": "Sagen tigezmi n ismal ifazen",
  "edit_topsites_showmore_button": "Sken ugar",
  "edit_topsites_showless_button": "Sken qel",
  "edit_topsites_done_button": "Immed",
  "edit_topsites_pin_button": "Ṭṭef asmel-agi",
  "edit_topsites_unpin_button": "Serreḥ asmel-agi",
  "edit_topsites_edit_button": "Ẓreg asmel-agi",
  "edit_topsites_dismiss_button": "Anef i usmel-agi",
  "edit_topsites_add_button": "Rnu",
  "topsites_form_add_header": "Asmel ifazen amaynut",
  "topsites_form_edit_header": "Ẓreg asmel ifazen",
  "topsites_form_title_placeholder": "Sekcem azwel",
  "topsites_form_url_placeholder": "Aru neɣ sekcem tansa URL",
  "topsites_form_add_button": "Rnu",
  "topsites_form_save_button": "Sekles",
  "topsites_form_cancel_button": "Sefsex",
  "topsites_form_url_validation": "Tansa URL tameɣtut tettwasra",
  "pocket_read_more": "Isental ittwasnen aṭas:",
  "pocket_read_even_more": "Wali ugar n teqsiḍin",
  "pocket_feedback_header": "D amezwaru n Web, ittwafren sγur ugar 25 imelyan n imdanen.",
  "pocket_description": "S lmendad n Pocket n Mozillan wali aqbur ifazen aṭas, s ttawil-a werǧin ad tzegleḍ taγawsa.",
  "highlights_empty_state": "Bdu tuniginn sakin nekkni ad k-n-sken imagraden, tividyutin, akked isebtar nniḍen i γef terziḍ yakan neγ i tceṛḍeḍ dagi.",
  "topstories_empty_state": "Ulac wiyaḍ. Uɣal-d ticki s wugar n imagraden seg {provider}. Ur tebɣiḍ ara ad terǧuḍ? Fren asentel seg wid yettwasnen akken ad twaliḍ imagraden yelhan di Web.",
  "manual_migration_explanation2": "Σreḍ Firefox s ticṛaḍ n isebtar, amazray akked awalen uffiren sγur ilinigen nniḍen.",
  "manual_migration_cancel_button": "Ala, tanemmirt",
  "manual_migration_import_button": "Kter tura"
};

==> firefox-61.0b6.source.tar.xz: firefox-61.0/browser/extensions/activity-stream/prerendered/locales/kab/activity-stream-strings.js <==
// Note - this is a generated kab file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Iccer amaynut",
  "header_top_sites": "Ismal ifazen",
  "header_highlights": "Asebrureq",
  "header_recommended_by": "Iwelleh-it-id {provider}",
  "context_menu_button_sr": "Ldi umuɣ asatal i {title}",
  "section_context_menu_button_sr": "Ldi umuɣ n usatal n tgezmi",
  "type_label_visited": "Yettwarza",
  "type_label_bookmarked": "Yettwacreḍ",
  "type_label_recommended": "Tiddin",
  "type_label_pocket": "Yettwakles ɣer Pocket",
  "type_label_downloaded": "Downloaded",
  "menu_action_bookmark": "Creḍ asebter-agi",
  "menu_action_remove_bookmark": "Kkes tacreṭ-agi",
  "menu_action_open_new_window": "Ldei deg usfaylu amaynut",
  "menu_action_open_private_window": "Ldi deg usfaylu uslig amaynut",
  "menu_action_dismiss": "Kkes",
  "menu_action_delete": "Kkes seg umazray",
  "menu_action_pin": "Senteḍ",
  "menu_action_unpin": "Serreḥ",
  "confirm_history_delete_p1": "Tebɣiḍ ad tekksed yal tummant n usebter-agi seg umazray-ik?",
  "confirm_history_delete_notice_p2": "Tigawt-agi ur tettuɣal ara ar deffir.",
  "menu_action_save_to_pocket": "Sekles ɣer Pocket",
  "menu_action_delete_pocket": "Kkes si Pocket",
  "menu_action_archive_pocket": "Ḥrez di Pocket",
  "menu_action_show_file_mac_os": "Show in Finder",
  "menu_action_show_file_windows": "Open Containing Folder",
  "menu_action_show_file_linux": "Open Containing Folder",
  "menu_action_show_file_default": "Show File",
  "menu_action_open_file": "Open File",
  "menu_action_copy_download_link": "Copy Download Link",
  "menu_action_go_to_download_page": "Go to Download Page",
  "menu_action_remove_download": "Remove from History",
  "search_button": "Nadi",
  "search_header": "Anadi {search_engine_name}",
  "search_web_placeholder": "Nadi di Web",
  "section_disclaimer_topstories": "Tiqṣiḍin ifazen ak deg Web, ttwafernent ilmend n wayen teqqareḍ. Seg Pocket i yuγal akka d aḥric n Mozilla.",
  "section_disclaimer_topstories_linktext": "Issin amek i teddu.",
  "section_disclaimer_topstories_buttontext": "Ih, awi-t-id",
  "prefs_home_header": "Agbur agejdan Firefox",
  "prefs_home_description": "Fren agbur i tebɣiḍ deg ugdil agejdan Firefox.",
  "prefs_section_rows_option": "{num} izirig;{num} izirigen",
  "prefs_search_header": "Anadi Web",
  "prefs_topsites_description": "Ismal i tettwaliḍ aṭas",
  "prefs_topstories_description2": "Great content from around the web, personalized for you",
  "prefs_topstories_options_sponsored_label": "Sponsored Stories",
  "prefs_topstories_sponsored_learn_more": "Issin ugar",
  "prefs_highlights_description": "Tafrant n yismal i teskelseḍ neɣ i twalaḍ",
  "prefs_highlights_options_visited_label": "Visited Pages",
  "prefs_highlights_options_download_label": "Most Recent Download",
  "prefs_highlights_options_pocket_label": "Pages Saved to Pocket",
  "prefs_snippets_description": "Ileqman seg Mozilla d Firefox",
  "settings_pane_button_label": "Sagen asebter n yiccer-ik amaynut",
  "settings_pane_topsites_header": "Ismal ifazen",
  "settings_pane_highlights_header": "Asebrureq",
  "settings_pane_highlights_options_bookmarks": "Ticraḍ n isebtar",
  "settings_pane_snippets_header": "Tiwzillin",
  "edit_topsites_button_text": "Ẓreg",
  "edit_topsites_edit_button": "Ẓreg asmel-agi",
  "topsites_form_add_header": "Asmel ifazen amaynut",
  "topsites_form_edit_header": "Ẓreg asmel ifazen",
  "topsites_form_title_label": "Azwel",
  "topsites_form_title_placeholder": "Sekcem azwel",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "Tugna tudmawant URL",
  "topsites_form_url_placeholder": "Aru neɣ sekcem tansa URL",
  "topsites_form_use_image_link": "Seqdec tugna tudmawant…",
  "topsites_form_preview_button": "Taskant",
  "topsites_form_add_button": "Rnu",
  "topsites_form_save_button": "Sekles",
  "topsites_form_cancel_button": "Sefsex",
  "topsites_form_url_validation": "Tansa URL tameɣtut tettwasra",
  "topsites_form_image_validation": "Tugna ur d-uli ara. Ɛreḍ tansa-nniḍen URL.",
  "pocket_read_more": "Isental ittwasnen aṭas:",
  "pocket_read_even_more": "Wali ugar n teqsiḍin",
  "highlights_empty_state": "Bdu tuniginn sakin nekkni ad k-n-sken imagraden, tividyutin, akked isebtar nniḍen i γef terziḍ yakan neγ i tceṛḍeḍ dagi.",
  "topstories_empty_state": "Ulac wiyaḍ. Uɣal-d ticki s wugar n imagraden seg {provider}. Ur tebɣiḍ ara ad terǧuḍ? Fren asentel seg wid yettwasnen akken ad twaliḍ imagraden yelhan di Web.",
  "manual_migration_explanation2": "Σreḍ Firefox s ticṛaḍ n isebtar, amazray akked awalen uffiren sγur ilinigen nniḍen.",
  "manual_migration_cancel_button": "Ala, tanemmirt",
  "manual_migration_import_button": "Kter tura",
  "error_fallback_default_info": "Ihuh, yella wayen yeḍran deg usali n ugbur-a.",
  "error_fallback_default_refresh_suggestion": "Sali-d aseter akken ad talseḍ aɛraḍ.",
  "section_menu_action_remove_section": "Kkes tigezmi",
  "section_menu_action_collapse_section": "Fneẓ tigezmi",
  "section_menu_action_expand_section": "Snefli tigezmi",
  "section_menu_action_manage_section": "Sefrek tigezmi",
  "section_menu_action_add_topsite": "Rnu asmel ifazen",
  "section_menu_action_move_up": "Ali",
  "section_menu_action_move_down": "Ader",
  "section_menu_action_privacy_notice": "Tasertit n tbaḍnit",
  "default_label_loading": "Asali…",
  "header_stories": "Tiqsiɣin ifazen",
  "header_visit_again": "Rzu tikelt-nniḍen",
  "header_bookmarks": "Ticraḍ n melmi kan",
  "header_bookmarks_placeholder": "Ur ɣur-k ara ticraḍ yakan.",
  "header_stories_from": "seg",
  "type_label_synced": "Yemtawi seg ibenk-nniḍen",
  "type_label_open": "Yeldi",
  "type_label_topic": "Asentel",
  "type_label_now": "Tura",
  "menu_action_copy_address": "Nγel tansa",
  "menu_action_email_link": "Azen aseγwen s yimayl…",
  "search_for_something_with": "Nadi γef {search_term} s:",
  "search_settings": "Snifel iγewwaṛen n unadi",
  "section_info_option": "Talɣut",
  "section_info_send_feedback": "Azen tikti",
  "section_info_privacy_notice": "Tasertit n tbaḍnit",
  "welcome_title": "Ansuf ar yiccer amaynut",
  "welcome_body": "Firefox ad iseqdec tallunt akken ad d-yesken akk ticraḍ n isebtar iwulmen, imagraden, tividyutin, akked isebtar aniɣer terziḍ melmi kan, ihi tzemreḍ ad d-uɣaleḍ ɣer-sen s wudem fessusen.",
  "welcome_label": "Asulu n iferdisen tisura",
  "time_label_less_than_minute": "<1 n tesdat",
  "time_label_minute": "{number} n tesdatin",
  "time_label_hour": "{number} n isragen",
  "time_label_day": "{number}n wussan",
  "prefs_restore_defaults_button": "Err-d eɣewwaṛen n tazwara",
  "prefs_topstories_description": "Agbur n tɣara meqqren i tzegleḍ ahat",
  "prefs_topstories_show_sponsored_label": "Tiqsiḍin yettwarefden {provider}",
  "settings_pane_header": "Ismenyifen n yiccer amaynut",
  "settings_pane_body2": "Fren ayen ad twaliḍ deg usebter-agi.",
  "settings_pane_search_header": "Nadi",
  "settings_pane_search_body": "Nadi di Web seg iccer-ik amaynut.",
  "settings_pane_topsites_body": "Kcem ar yesmal web i trezzuḍ s waṭas.",
  "settings_pane_topsites_options_showmore": "Sken sin izirigen",
  "settings_pane_bookmarks_header": "Ticraḍ n melmi kan",
  "settings_pane_bookmarks_body": "Ticraḍ yettwarnan melmi kan deg iwen n umdiq ɣef afus.",
  "settings_pane_visit_again_header": "Rzu tikelt-nniḍen",
  "settings_pane_visit_again_body": "Firefox ad d-yesken tukkist n umazray-ik n tunigin i tzemreḍ ad twalid tikelt-nniḍen.",
  "settings_pane_highlights_body2": "Aff abrid-ik γer wayen i tḥemmleḍ i γef terziḍ yakan neγ tcerḍeḍ-t.",
  "settings_pane_highlights_options_visited": "Ismal yettwarzan",
  "settings_pane_snippets_body": "Wali issalen n Mozilla γef Firefox, adlis internet, akked issalen nniṣen sya γer da.",
  "settings_pane_done_button": "Immed",
  "settings_pane_topstories_options_sponsored": "Sken Imagraden yesɛan imasayen",
  "edit_topsites_button_label": "Sagen tigezmi n ismal ifazen",
  "edit_topsites_showmore_button": "Sken ugar",
  "edit_topsites_showless_button": "Sken qel",
  "edit_topsites_done_button": "Immed",
  "edit_topsites_pin_button": "Ṭṭef asmel-agi",
  "edit_topsites_unpin_button": "Serreḥ asmel-agi",
  "edit_topsites_dismiss_button": "Anef i usmel-agi",
  "edit_topsites_add_button": "Rnu",
  "pocket_feedback_header": "D amezwaru n Web, ittwafren sγur ugar 25 imelyan n imdanen.",
  "pocket_description": "S lmendad n Pocket n Mozillan wali aqbur ifazen aṭas, s ttawil-a werǧin ad tzegleḍ taγawsa."
};
